/*
   Copyright (C) 2018-2020 Laurent Montel <montel@kde.org>

   This library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Library General Public
   License as published by the Free Software Foundation; either
   version 2 of the License, or (at your option) any later version.

   This library is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   Library General Public License for more details.

   You should have received a copy of the GNU Library General Public License
   along with this library; see the file COPYING.LIB.  If not, write to
   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
   Boston, MA 02110-1301, USA.
*/

#ifndef DKIMAUTHENTICATIONSTATUSINFOTEST_H
#define DKIMAUTHENTICATIONSTATUSINFOTEST_H

#include <QObject>

class DKIMAuthenticationStatusInfoTest : public QObject
{
    Q_OBJECT
public:
    explicit DKIMAuthenticationStatusInfoTest(QObject *parent = nullptr);
    ~DKIMAuthenticationStatusInfoTest() = default;

private Q_SLOTS:
    void shouldHaveDefaultValue();
    void shouldParseKey();
    void shouldParseKey_data();
};

#endif // DKIMAUTHENTICATIONSTATUSINFOTEST_H
